@@ -1,33 +1,45 @@
-## Copyright (C) 1995-2015 John W. Eaton
+########################################################################
+##
+## Copyright (C) 1995-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {} subplot (@var{rows}, @var{cols}, @var{index})
-## @deftypefnx {Function File} {} subplot (@var{rcn})
-## @deftypefnx {Function File} {} subplot (@var{hax})
-## @deftypefnx {Function File} {} subplot (@dots{}, "align")
-## @deftypefnx {Function File} {} subplot (@dots{}, "replace")
-## @deftypefnx {Function File} {} subplot (@dots{}, "position", @var{pos})
-## @deftypefnx {Function File} {} subplot (@dots{}, @var{prop}, @var{val}, @dots{})
-## @deftypefnx {Function File} {@var{hax} =} subplot (@dots{})
+## @deftypefn  {} {} subplot (@var{rows}, @var{cols}, @var{index})
+## @deftypefnx {} {} subplot (@var{rows}, @var{cols}, @var{index}, @var{hax})
+## @deftypefnx {} {} subplot (@var{rcn})
+## @deftypefnx {} {} subplot (@var{hax})
+## @deftypefnx {} {} subplot (@dots{}, "align")
+## @deftypefnx {} {} subplot (@dots{}, "replace")
+## @deftypefnx {} {} subplot ("position", @var{pos})
+## @deftypefnx {} {} subplot (@dots{}, @var{prop}, @var{val}, @dots{})
+## @deftypefnx {} {@var{hax} =} subplot (@dots{})
 ## Set up a plot grid with @var{rows} by @var{cols} subwindows and set the
 ## current axes for plotting (@code{gca}) to the location given by @var{index}.
 ##
+## If an axes handle @var{hax} is provided after the (@var{rows}, @var{cols},
+## @var{index}) arguments, the corresponding axes is turned into a
+## subplot.
+##
 ## If only one numeric argument is supplied, then it must be a three digit
 ## value specifying the number of rows in digit 1, the number of columns in
 ## digit 2, and the plot index in digit 3.
@@ -59,7 +71,7 @@
 ##
 ## @end ifnottex
 ##
-## @var{index} may also be a vector.  In this case, the new axis will enclose
+## @var{index} may also be a vector.  In this case, the new axes will enclose
 ## the grid locations specified.  The first demo illustrates this:
 ##
 ## @example
@@ -70,10 +82,10 @@
 ## handle, @var{hax}, returned from a previous @code{subplot} command.
 ##
 ## If the option @qcode{"align"} is given then the plot boxes of the subwindows
-## will align, but this may leave no room for axis tick marks or labels.
+## will align, but this may leave no room for axes tick marks or labels.
 ##
-## If the option @qcode{"replace"} is given then the subplot axis will be
-## reset, rather than just switching the current axis for plotting to the
+## If the option @qcode{"replace"} is given then the subplot axes will be
+## reset, rather than just switching the current axes for plotting to the
 ## requested subplot.
 ##
 ## The @qcode{"position"} property can be used to exactly position the subplot
@@ -82,22 +94,51 @@
 ## The values in @var{pos} are normalized in the range [0,1].
 ##
 ## Any property/value pairs are passed directly to the underlying axes object.
+## The full list of properties is documented at @ref{Axes Properties}.
 ##
-## If the output @var{hax} is requested, subplot returns the axis handle for
+## Any previously existing axes that would be (partly) covered by the newly
+## created axes are deleted.
+##
+## If the output @var{hax} is requested, subplot returns the axes handle for
 ## the subplot.  This is useful for modifying the properties of a subplot
 ## using @code{set}.
+##
+## Under some circumstances, @code{subplot} might not be able to identify axes
+## that it could re-use and might replace them.  If @code{subplot} axes
+## should be referenced repeatedly, consider creating and storing their axes
+## handles beforehand instead of calling @code{subplot} repeatedly for the same
+## position.
+##
+## Example:
+## @example
+## @group
+## x = 1:10;
+## y = rand (16, 10);
+## for i_plot = 1:4
+##   hax(i_plot) = subplot (2, 2, i_plot);
+##   hold (hax(i_plot), "on");
+##   grid (hax(i_plot), "on");
+## endfor
+## for i_loop = 1:2
+##   for i_plot = 1:4
+##     iy = (i_loop - 1)*4 + i_plot;
+##     plotyy (hax(i_plot), x,y(iy,:), x,y(iy+1,:));
+##   endfor
+##  endfor
+## @end group
+## @end example
+##
 ## @seealso{axes, plot, gca, set}
 ## @end deftypefn
 
-## Author: Vinayak Dutt <Dutt.Vinayak@mayo.EDU>
-## Adapted-By: jwe
-
 function h = subplot (varargin)
 
   align_axes = false;
   replace_axes = false;
   have_position = false;
   initial_args_decoded = false;
+  make_subplot = false;
+  hsubplot = [];
 
   if (nargin >= 3)
     ## R, C, N?
@@ -110,7 +151,13 @@ function h = subplot (varargin)
       rows = arg1;
       cols = arg2;
       index = arg3;
-      varargin(1:3) = [];
+      if (nargin > 3 && isaxes (varargin{4}))
+        make_subplot = true;
+        hsubplot = varargin{4};
+        varargin(1:4) = [];
+      else
+        varargin(1:3) = [];
+      endif
       initial_args_decoded = true;
     endif
   endif
@@ -148,7 +195,7 @@ function h = subplot (varargin)
       varargin(1) = [];
       initial_args_decoded = true;
     else
-      error ("subplot: expecting axes handle or RCN argument");
+      error ("subplot: invalid axes handle or RCN argument");
     endif
   endif
 
@@ -166,7 +213,7 @@ function h = subplot (varargin)
     endif
 
     if (rows < 1 || cols < 1 || index < 1)
-      error ("subplot: ROWS, COLS, and INDEX must be be positive");
+      error ("subplot: ROWS, COLS, and INDEX must be positive");
     endif
   endif
 
@@ -211,69 +258,90 @@ function h = subplot (varargin)
 
     set (cf, "nextplot", "add");
 
-    found = false;
-    kids = get (cf, "children");
-    for child = kids(:)'
-      ## Check whether this child is still valid; this might not be the
-      ## case anymore due to the deletion of previous children (due to
-      ## "deletefcn" callback or for legends/colorbars that are deleted
-      ## with their corresponding axes).
-      if (! ishandle (child))
-        continue;
-      endif
-      if (strcmp (get (child, "type"), "axes"))
-        ## Skip legend and colorbar objects.
-        if (any (strcmp (get (child, "tag"), {"legend", "colorbar"})))
+    if (! make_subplot)
+      found = false;
+      kids = get (cf, "children");
+      for child = kids(:)'
+        ## Check whether this child is still valid; this might not be the
+        ## case anymore due to the deletion of previous children (due to
+        ## "deletefcn" callback or for legends/colorbars that are deleted
+        ## with their corresponding axes).
+        if (! ishghandle (child))
           continue;
         endif
+        if (strcmp (get (child, "type"), "axes"))
+          ## Skip legend and colorbar objects.
+          if (any (strcmp (get (child, "tag"), {"legend", "colorbar"})))
+            continue;
+          endif
 
-        if (isappdata (child, "__subplotposition__"))
-          objpos = getappdata (child, "__subplotposition__");
-        else
-          objpos = get (child, "position");
-        endif
-        if (all (abs (objpos - pos) < eps) && ! replace_axes)
-          ## If the new axes are in exactly the same position
-          ## as an existing axes object, or if they share the same
-          ## appdata "__subplotposition__", use the existing axes.
-          found = true;
-          hsubplot = child;
-        else
-          ## If the new axes overlap an old axes object, delete the old axes.
-          objpos = get (child, "position");
+          if (! replace_axes)
+            if (isappdata (child, "__subplotposition__"))
+              objpos = getappdata (child, "__subplotposition__");
+            else
+              objpos = get (child, "position");
+            endif
+            if (all (abs (objpos - pos) < eps))
+              ## If the new axes are in exactly the same position
+              ## as an existing axes object, or if they share the same
+              ## appdata "__subplotposition__", use the existing axes.
+              found = true;
+              hsubplot = child;
+            else
+              ## Check if this axes is a subplot with the same layout and
+              ## index as the requested one
+              rcn = getappdata (child, "__subplotrcn__");
+              if (all (size (rcn) == [1 3])
+                  && rcn{1} == rows && rcn{2} == cols && all (rcn{3} == index))
+                found = true;
+                hsubplot = child;
+              endif
+            endif
+          endif
 
-          x0 = pos(1);
-          x1 = x0 + pos(3);
-          y0 = pos(2);
-          y1 = y0 + pos(4);
-          objx0 = objpos(1);
-          objx1 = objx0 + objpos(3);
-          objy0 = objpos(2);
-          objy1 = objy0 + objpos(4);
-          if (! (x0 >= objx1 || x1 <= objx0 || y0 >= objy1 || y1 <= objy0))
-            delete (child);
+          if (! found)
+            ## If the new axes overlap an old axes object, delete the old axes.
+            objpos = get (child, "position");
+
+            x0 = pos(1);
+            x1 = x0 + pos(3);
+            y0 = pos(2);
+            y1 = y0 + pos(4);
+            objx0 = objpos(1);
+            objx1 = objx0 + objpos(3);
+            objy0 = objpos(2);
+            objy1 = objy0 + objpos(4);
+            if (! (x0 >= objx1 || x1 <= objx0 || y0 >= objy1 || y1 <= objy0))
+              delete (child);
+            endif
           endif
         endif
-      endif
-    endfor
+      endfor
+    else
+      found = true;
+    endif
 
-    if (found)
+    if (found && ! make_subplot)
       ## Switch to existing subplot and set requested properties
       set (cf, "currentaxes", hsubplot);
       if (! isempty (varargin))
         set (hsubplot, varargin{:});
       endif
     else
-      hsubplot = axes ("box", "off",
-                       "activepositionproperty", "position",
-                       "position", pos, "looseinset", li,
-                       varargin{:});
+      pval = [{"activepositionproperty", "position", ...
+               "position", pos, "looseinset", li} varargin];
+      if (! make_subplot)
+        hsubplot = axes (pval{:});
+      else
+        set (hsubplot, pval{:})
+      endif
 
       if (! align_axes)
         ## base position (no ticks, no annotation, no cumbersome neighbor)
         setappdata (hsubplot, "__subplotposition__", pos);
         ## max outerposition
         setappdata (hsubplot, "__subplotouterposition__", opos);
+        setappdata (hsubplot, "__subplotrcn__", {rows, cols, index});
         addlistener (hsubplot, "outerposition", @subplot_align);
         addlistener (hsubplot, "xaxislocation", @subplot_align);
         addlistener (hsubplot, "yaxislocation", @subplot_align);
@@ -368,10 +436,11 @@ endfunction
 
 function subplot_align (h, d, rmupdate = false)
   persistent updating = false;
+
   if (! updating)
     if (rmupdate)
-      ## The "position" property has been changed from outside this
-      ## routine. Don't update anymore.
+      ## The "position" property has been changed from outside this routine.
+      ## Don't update anymore.
       if (isappdata (h, "__subplotposition__"))
         rmappdata (h, "__subplotposition__");
         rmappdata (h, "__subplotouterposition__");
@@ -396,8 +465,8 @@ function subplot_align (h, d, rmupdate = false)
       hsubplots = children(do_align);
 
 
-      ## There may be mixed subplot series (e.g. 2-by-6 and 1-by-6) in
-      ## the same figure. Only subplots that have the same width and
+      ## There may be mixed subplot series (e.g., 2-by-6 and 1-by-6) in
+      ## the same figure.  Only subplots that have the same width and
       ## height as this one are updated.
       if (any (h == hsubplots))
         width = pos(h == hsubplots, 3);
@@ -414,7 +483,7 @@ function subplot_align (h, d, rmupdate = false)
       if (iscell (opos))
         opos = cell2mat (opos);
       endif
-      for ii = 1:numel (hsubplots);
+      for ii = 1:numel (hsubplots)
         set (hsubplots(ii), "outerposition", opos(ii,:), ...
              "activepositionproperty", "position");
       endfor
@@ -454,96 +523,97 @@ endfunction
 %! clf;
 %! r = 3;
 %! c = 3;
-%! fmt = {'horizontalalignment', 'center', 'verticalalignment', 'middle'};
+%! fmt = {"horizontalalignment", "center", "verticalalignment", "middle"};
 %! for n = 1 : r*c
 %!   subplot (r, c, n);
-%!   xlabel (sprintf ('xlabel #%d', n));
-%!   ylabel (sprintf ('ylabel #%d', n));
-%!   title (sprintf ('title #%d', n));
-%!   text (0.5, 0.5, sprintf ('subplot(%d,%d,%d)', r, c, n), fmt{:});
-%!   axis ([0 1 0 1]);
-%! end
+%!    xlabel (sprintf ("xlabel #%d", n));
+%!    ylabel (sprintf ("ylabel #%d", n));
+%!    title (sprintf ("title #%d", n));
+%!    text (0.5, 0.5, sprintf ("subplot(%d,%d,%d)", r, c, n), fmt{:});
+%!    axis ([0 1 0 1]);
+%! endfor
 %! subplot (r, c, 1:3);
-%! xlabel (sprintf ('xlabel #%d:%d', 1, 3));
-%! ylabel (sprintf ('ylabel #%d:%d', 1, 3));
-%! title (sprintf ('title #%d:%d', 1, 3));
-%! text (0.5, 0.5, sprintf ('subplot(%d,%d,%d:%d)', r, c, 1, 3), fmt{:});
+%!  xlabel (sprintf ("xlabel #%d:%d", 1, 3));
+%!  ylabel (sprintf ("ylabel #%d:%d", 1, 3));
+%!  title (sprintf ("title #%d:%d", 1, 3));
+%!  text (0.5, 0.5, sprintf ("subplot(%d,%d,%d:%d)", r, c, 1, 3), fmt{:});
 %! axis ([0 1 0 1]);
 
 %!demo
 %! clf;
 %! x = 0:1;
 %! for n = 1:4
-%!   subplot (2,2,n, 'align');
-%!   plot (x, x);
-%!   xlabel (sprintf ('xlabel (2,2,%d)', n));
-%!   ylabel (sprintf ('ylabel (2,2,%d)', n));
-%!   title (sprintf ('title (2,2,%d)', n));
-%! end
-%! subplot (1,2,1, 'align');
-%! plot (x, x);
-%! xlabel ('xlabel (1,2,1)');
-%! ylabel ('ylabel (1,2,1)');
-%! title ('title (1,2,1)');
+%!   subplot (2,2,n, "align");
+%!    plot (x, x);
+%!    xlabel (sprintf ("xlabel (2,2,%d)", n));
+%!    ylabel (sprintf ("ylabel (2,2,%d)", n));
+%!    title (sprintf ("title (2,2,%d)", n));
+%! endfor
+%! subplot (1,2,1, "align");
+%!  plot (x, x);
+%!  xlabel ("xlabel (1,2,1)");
+%!  ylabel ("ylabel (1,2,1)");
+%!  title ("title (1,2,1)");
 
 %!demo
 %! clf;
 %! x = 0:10;
 %! ax(1) = subplot (221);
-%! set (ax(1), 'tag', '1');
-%! plot (x, rand (3, 11))
-%! title ('x & y labels & ticklabels');
-%! xlabel xlabel
-%! ylabel ylabel
+%! set (ax(1), "tag", "1");
+%! plot (x, rand (3, 11));
+%! title ("x & y labels & ticklabels");
+%! xlabel xlabel;
+%! ylabel ylabel;
 %! ax(2) = subplot (222);
-%! set (ax(2), 'tag', '2');
-%! plot (x, rand (3, 11))
-%! title ('no labels');
-%! axis ('nolabel','tic')
+%! set (ax(2), "tag", "2");
+%! plot (x, rand (3, 11));
+%! title ("no labels");
+%! axis ("nolabel","tic");
 %! ax(3) = subplot (223);
-%! set (ax(3), 'tag', '3');
-%! plot (x, rand (3, 11))
-%! title ('no labels');
-%! axis ('nolabel','tic')
+%! set (ax(3), "tag", "3");
+%! plot (x, rand (3, 11));
+%! title ("no labels");
+%! axis ("nolabel","tic");
 %! ax(4) = subplot (224);
-%! set (ax(4), 'tag', '4');
-%! plot (x, rand (3, 11))
-%! title ('x & y labels & ticklabels');
-%! xlabel xlabel
-%! ylabel ylabel
+%! set (ax(4), "tag", "4");
+%! plot (x, rand (3, 11));
+%! title ("x & y labels & ticklabels");
+%! xlabel xlabel;
+%! ylabel ylabel;
 
 %!demo
+%! clf;
 %! x = 0:10;
 %! subplot (221);
-%! plot (x, rand (3, 11))
-%! ylim ([0, 1]);
-%! text (0.5, 0.5, '{x,y}labels & {x,y}ticklabels', ...
-%!       'horizontalalignment', 'center', ...
-%!       'units', 'normalized');
-%! xlabel xlabel
-%! ylabel ylabel
-%! title title
+%!  plot (x, rand (3, 11));
+%!  ylim ([0, 1]);
+%!  text (0.5, 0.5, "{x,y}labels & {x,y}ticklabels", ...
+%!                  "horizontalalignment", "center", ...
+%!                  "units", "normalized");
+%!  xlabel xlabel;
+%!  ylabel ylabel;
+%!  title title;
 %! subplot (222);
-%! plot (x, rand (3, 11))
-%! axis ('labely');
-%! ylabel ylabel
-%! text (0.5, 0.5, 'no xlabels, xticklabels', ...
-%!       'horizontalalignment', 'center', ...
-%!       'units', 'normalized');
+%!  plot (x, rand (3, 11));
+%!  axis ("labely");
+%!  ylabel ylabel;
+%!  text (0.5, 0.5, "no xlabels, xticklabels", ...
+%!                  "horizontalalignment", "center", ...
+%!                  "units", "normalized");
 %! subplot (223);
-%! plot (x, rand (3, 11))
-%! axis ('labelx');
-%! text (0.5, 0.5, 'no ylabels, yticklabels', ...
-%!       'horizontalalignment', 'center', ...
-%!       'units', 'normalized');
-%! xlabel xlabel
-%! title title
+%!  plot (x, rand (3, 11));
+%!  axis ("labelx");
+%!  text (0.5, 0.5, "no ylabels, yticklabels", ...
+%!                  "horizontalalignment", "center", ...
+%!                  "units", "normalized");
+%!  xlabel xlabel;
+%!  title title;
 %! subplot (224);
-%! plot (x, rand (3, 11))
-%! axis ('nolabel','tic');
-%! text (0.5, 0.5, 'no {x,y}labels, {x,y}ticklabels', ...
-%!       'horizontalalignment', 'center', ...
-%!       'units', 'normalized');
+%!  plot (x, rand (3, 11));
+%!  axis ("nolabel", "tic");
+%!  text (0.5, 0.5, "no {x,y}labels, {x,y}ticklabels", ...
+%!                  "horizontalalignment", "center", ...
+%!                  "units", "normalized");
 
 ## Test recognition/deletion of previous axes
 ## Default mode
@@ -556,7 +626,7 @@ endfunction
 %!   subplot (3,3,1);
 %!   assert (gca (), hax(1));
 %!   subplot (2,1,1);
-%!   assert (ishandle (hax),[false(1,6), true(1,3)]);
+%!   assert (ishghandle (hax),[false(1,6), true(1,3)]);
 %! unwind_protect_cleanup
 %!   delete (hf);
 %! end_unwind_protect
@@ -572,7 +642,7 @@ endfunction
 %!   subplot ("position", [0.5 0.5 0.3 0.3]);
 %!   assert (gca (), h2);
 %!   subplot ("position", [0.5 0.5 0.3 0.2]);
-%!   assert (! ishandle (h2));
+%!   assert (! ishghandle (h2));
 %! unwind_protect_cleanup
 %!   delete (hf);
 %! end_unwind_protect
@@ -586,8 +656,8 @@ endfunction
 %!   subplot (3,5,1, "align");
 %!   assert (gca (), h1);
 %!   subplot (3,2,1, "align");
-%!   assert (! ishandle (h1));
-%!   assert (! ishandle (h2));
+%!   assert (! ishghandle (h1));
+%!   assert (! ishghandle (h2));
 %! unwind_protect_cleanup
 %!   delete (hf);
 %! end_unwind_protect
