@@ -1,27 +1,32 @@
-## Copyright (C) 2001, 2013 David Billinghurst
-## Copyright (C) 2001, 2013 Paul Kienzle
-## Copyright (C) 2003, 2013 Jaakko Ruohio
+########################################################################
+##
+## Copyright (C) 2001-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {@var{k} =} ellipke (@var{m})
-## @deftypefnx {Function File} {@var{k} =} ellipke (@var{m}, @var{tol})
-## @deftypefnx {Function File} {[@var{k}, @var{e}] =} ellipke (@dots{})
+## @deftypefn  {} {@var{k} =} ellipke (@var{m})
+## @deftypefnx {} {@var{k} =} ellipke (@var{m}, @var{tol})
+## @deftypefnx {} {[@var{k}, @var{e}] =} ellipke (@dots{})
 ## Compute complete elliptic integrals of the first K(@var{m}) and second
 ## E(@var{m}) kind.
 ##
@@ -83,10 +88,6 @@
 ## @seealso{ellipj}
 ## @end deftypefn
 
-## Author: David Billinghurst <David.Billinghurst@riotinto.com>
-## Author: Paul Kienzle <pkienzle@users.sf.net>
-## Author: Jaakko Ruohio
-
 function [k, e] = ellipke (m, tol = [])
 
   if (nargin < 1 || nargin > 2)
@@ -103,7 +104,7 @@ function [k, e] = ellipke (m, tol = [])
   if (isempty (tol))
     tol = eps (class (m));
   elseif (! (isreal (tol) && isscalar (tol) && tol > 0))
-    error ("ellipke: TOL must be a real scalar > 0")
+    error ("ellipke: TOL must be a real scalar > 0");
   endif
 
   k = e = zeros (sz);
@@ -120,9 +121,9 @@ function [k, e] = ellipke (m, tol = [])
   ## Arithmetic-Geometric Mean (AGM) algorithm
   ## ( Abramowitz and Stegun, Section 17.6 )
   Nmax = 16;
-  idx = !idx_1 & !idx_neginf;
+  idx = ! idx_1 & ! idx_neginf;
   if (any (idx))
-    idx_neg = find (m < 0 & !idx_neginf);
+    idx_neg = find (m < 0 & ! idx_neginf);
     mult_k = 1./sqrt (1 - m(idx_neg));
     mult_e = sqrt (1 - m(idx_neg));
     m(idx_neg) = -m(idx_neg) ./ (1 - m(idx_neg));
@@ -225,4 +226,3 @@ endfunction
 %!error <TOL must be a real scalar . 0> ellipke (1, i)
 %!error <TOL must be a real scalar . 0> ellipke (1, [1 1])
 %!error <TOL must be a real scalar . 0> ellipke (1, -1)
-
